<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AppLauncher</name>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="40"/>
        <source>App Launcher</source>
        <translation>Uruchamianie aplikacji</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="52"/>
        <source>Choose an app to open the capture</source>
        <translation>Wybierz aplikację do otwierania zrzutu</translation>
    </message>
</context>
<context>
    <name>AppLauncherWidget</name>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="56"/>
        <source>Open With</source>
        <translation>Otwórz w</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="71"/>
        <source>Launch in terminal</source>
        <translation>Otwórz w terminalu</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="72"/>
        <source>Keep open after selection</source>
        <translation>Pozostaw otwarte po zaznaczeniu</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <source>Unable to write in</source>
        <translation>Nie można zapisać</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Unable to launch in terminal.</source>
        <translation>Nie można uruchomić w terminalu.</translation>
    </message>
</context>
<context>
    <name>ArrowTool</name>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="92"/>
        <source>Arrow</source>
        <translation>Strzałka</translation>
    </message>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="104"/>
        <source>Set the Arrow as the paint tool</source>
        <translation>Rysowanie strzałek</translation>
    </message>
</context>
<context>
    <name>BlurTool</name>
    <message>
        <source>Blur</source>
        <translation type="vanished">Rozmycie</translation>
    </message>
    <message>
        <source>Set Blur as the paint tool</source>
        <translation type="vanished">Rozmywanie obszarów</translation>
    </message>
</context>
<context>
    <name>CaptureLauncher</name>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="67"/>
        <source>&lt;b&gt;Capture Mode&lt;/b&gt;</source>
        <translation>&lt;b&gt;Tryb przechwytywania&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="73"/>
        <source>Rectangular Region</source>
        <translation>Zaznaczony obszar</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="75"/>
        <source>Full Screen (All Monitors)</source>
        <translation>Pełny ekran (Wszystkie monitory)</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="83"/>
        <source>No Delay</source>
        <translation>Bez opóźnienia</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> second</source>
        <translation> sekunda</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> seconds</source>
        <translation> sekundy</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="94"/>
        <source>Take new screenshot</source>
        <translation>Wykonaj nowy zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="103"/>
        <source>Area:</source>
        <translation>Obszar:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="104"/>
        <source>Delay:</source>
        <translation>Opóźnienie:</translation>
    </message>
</context>
<context>
    <name>CaptureWidget</name>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="99"/>
        <source>Unable to capture screen</source>
        <translation>Nie można przechwycić ekranu</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="260"/>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.
Press Space to open the side panel.</source>
        <translation>Wybierz obszar za pomocą myszy lub wciśnij Esc aby wyjść.
Wciśnij Enter, aby wykonać zrzut ekranu.
Prawy klik, aby pokazać próbnik kolorów.
Spacja, aby pokazać panel boczny.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="617"/>
        <source>Tool Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CircleCountTool</name>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="39"/>
        <source>Circle Counter</source>
        <translation>Licznik</translation>
    </message>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="51"/>
        <source>Add an autoincrementing counter bubble</source>
        <translation>Dodaj automatycznie zwiększający się bąbelek licznika</translation>
    </message>
</context>
<context>
    <name>CircleTool</name>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="40"/>
        <source>Circle</source>
        <translation>Okręgi</translation>
    </message>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="52"/>
        <source>Set the Circle as the paint tool</source>
        <translation>Rysowanie okręgów i elips</translation>
    </message>
</context>
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="43"/>
        <source>Configuration</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="63"/>
        <source>Interface</source>
        <translation>Interfejs</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="69"/>
        <source>Filename Editor</source>
        <translation>Edytor nazw plików</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="73"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../src/core/controller.cpp" line="204"/>
        <source>&amp;Take Screenshot</source>
        <translation>&amp;Zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="209"/>
        <source>&amp;Open Launcher</source>
        <translation>Pokaż &amp;okno</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="212"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Konfiguracja</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="215"/>
        <source>&amp;About</source>
        <translation>O progr&amp;amie</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="vanished">&amp;Informacje</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="217"/>
        <source>&amp;Quit</source>
        <translation>&amp;Wyjdź</translation>
    </message>
</context>
<context>
    <name>CopyTool</name>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="41"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="53"/>
        <source>Copy the selection into the clipboard</source>
        <translation>Kopiuj zaznaczony obszar do schowka</translation>
    </message>
</context>
<context>
    <name>DBusUtils</name>
    <message>
        <location filename="../../src/utils/dbusutils.cpp" line="52"/>
        <source>Unable to connect via DBus</source>
        <translation>Nie można się połączyć za pomocą DBus</translation>
    </message>
</context>
<context>
    <name>ExitTool</name>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="40"/>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="52"/>
        <source>Leave the capture screen</source>
        <translation>Opuść ekran przechwytywania</translation>
    </message>
</context>
<context>
    <name>FileNameEditor</name>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="39"/>
        <source>Edit the name of your captures:</source>
        <translation>Edycja wzorca nazwy plików:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="43"/>
        <source>Edit:</source>
        <translation>Edytuj:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="45"/>
        <source>Preview:</source>
        <translation>Podgląd:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="88"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="91"/>
        <source>Saves the pattern</source>
        <translation>Zapisuje wzorzec</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="93"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="96"/>
        <source>Restores the saved pattern</source>
        <translation>Resetuje wzorzec</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="98"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="102"/>
        <source>Deletes the name</source>
        <translation>Czyści wzorzec</translation>
    </message>
</context>
<context>
    <name>GeneneralConf</name>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="121"/>
        <location filename="../../src/config/geneneralconf.cpp" line="258"/>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <source>Unable to read file.</source>
        <translation>Nie można odczytać pliku.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <source>Unable to write file.</source>
        <translation>Nie można zapisać pliku.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="147"/>
        <source>Save File</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="170"/>
        <source>Confirm Reset</source>
        <translation>Potwierdź Reset</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="171"/>
        <source>Are you sure you want to reset the configuration?</source>
        <translation>Czy na pewno chcesz zresetować konfigurację?</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="181"/>
        <source>Show help message</source>
        <translation>Pokaż podpowiedzi</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="185"/>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation>Pokaż podpowiedzi na początku trybu przechwytywania.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="196"/>
        <source>Show the side panel button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="199"/>
        <source>Show the side panel toggle button in the capture mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="210"/>
        <location filename="../../src/config/geneneralconf.cpp" line="214"/>
        <source>Show desktop notifications</source>
        <translation>Pokaż powiadomienia ekranowe</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="227"/>
        <source>Show tray icon</source>
        <translation>Pokaż ikonę w trayu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="231"/>
        <source>Show the systemtray icon</source>
        <translation>Pokaż ikonę w zasobniku systemowym</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="246"/>
        <source>Configuration File</source>
        <translation>Plik konfiguracyjny</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="251"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="265"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="276"/>
        <source>Launch at startup</source>
        <translation>Uruchom podczas startu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="280"/>
        <source>Launch Flameshot</source>
        <translation>Uruchom Flameshot</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="290"/>
        <source>Close after capture</source>
        <translation>Zamknij po wykonaniu zrzutu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="294"/>
        <source>Close after taking a screenshot</source>
        <translation>Zamknij po wykonaniu zrzutu ekranu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="306"/>
        <source>Copy URL after upload</source>
        <translation>Kopiuj adres URL po wysłaniu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="311"/>
        <source>Copy URL and close window after upload</source>
        <translation>Kopiuj adres URL po wysłaniu i zamknij okno</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="322"/>
        <source>Save image after copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="323"/>
        <source>Save image file after copying it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="332"/>
        <source>Save Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="344"/>
        <source>Change...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="363"/>
        <source>Choose a Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Unable to write to directory.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="48"/>
        <source>Upload to Imgur</source>
        <translation>Wyślij do Imgur</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="55"/>
        <source>Uploading Image</source>
        <translation>Wysyłanie obrazka</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="156"/>
        <source>Copy URL</source>
        <translation>Kopiuj URL</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="157"/>
        <source>Open URL</source>
        <translation>Otwórz URL</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="158"/>
        <source>Delete image</source>
        <translation>Usuń obrazek</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="159"/>
        <source>Image to Clipboard.</source>
        <translation>Obrazek do schowka.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="184"/>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="200"/>
        <source>Unable to open the URL.</source>
        <translation>Nie można otworzyć adresu URL.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="192"/>
        <source>URL copied to clipboard.</source>
        <translation>URL skopiowany do schowka.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="208"/>
        <source>Screenshot copied to clipboard.</source>
        <translation>Zrzut ekranu skopiowany do schowka.</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderTool</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="41"/>
        <source>Image Uploader</source>
        <translation>Uploader obrazów</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="53"/>
        <source>Upload the selection to Imgur</source>
        <translation>Wyślij zaznaczenie do Imgur</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="40"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="62"/>
        <source>SPACEBAR</source>
        <translation>SPACJA</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="63"/>
        <source>Right Click</source>
        <translation>Prawy klik</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="64"/>
        <source>Mouse Wheel</source>
        <translation>Kółko myszy</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="67"/>
        <source>Move selection 1px</source>
        <translation>Przesuń zaznaczenie o 1px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="68"/>
        <source>Resize selection 1px</source>
        <translation>Zmień rozmiar zaznaczenia o 1px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="69"/>
        <source>Quit capture</source>
        <translation>Zakończ przechwytywanie</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="70"/>
        <source>Copy to clipboard</source>
        <translation>Kopiuj do schowka</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="71"/>
        <source>Save selection as a file</source>
        <translation>Zapisz zaznaczenie jako plik</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="72"/>
        <source>Undo the last modification</source>
        <translation>Cofnij ostatnią modyfikację</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="73"/>
        <source>Toggle visibility of sidebar with options of the selected tool</source>
        <translation>Przełącz widoczność paska bocznego z opcjami wybranego narzędzia</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="74"/>
        <source>Show color picker</source>
        <translation>Pokaż próbnik kolorów</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="75"/>
        <source>Change the tool&apos;s thickness</source>
        <translation>Zmień grubość narzędzia</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="82"/>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation>Dostępne skróty w trybie przechwytywania obrazu.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Key</source>
        <translation>Klawisz</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Description</source>
        <translation>Działanie</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="126"/>
        <source>&lt;u&gt;&lt;b&gt;License&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Licencja&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="134"/>
        <source>&lt;u&gt;&lt;b&gt;Version&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Wersja&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="145"/>
        <source>&lt;u&gt;&lt;b&gt;Shortcuts&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Skróty klawiszowe&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
</context>
<context>
    <name>LineTool</name>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="43"/>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="55"/>
        <source>Set the Line as the paint tool</source>
        <translation>Ustawia linię jako narzędzie do rysowania</translation>
    </message>
</context>
<context>
    <name>MarkerTool</name>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="43"/>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="55"/>
        <source>Set the Marker as the paint tool</source>
        <translation>Ustawia Marker jako narzędzie rysowania</translation>
    </message>
</context>
<context>
    <name>MoveTool</name>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="40"/>
        <source>Move</source>
        <translation>Przesuwanie</translation>
    </message>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="52"/>
        <source>Move the selection area</source>
        <translation>Przesuwa zaznaczenie</translation>
    </message>
</context>
<context>
    <name>PencilTool</name>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="34"/>
        <source>Pencil</source>
        <translation>Ołówek</translation>
    </message>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="46"/>
        <source>Set the Pencil as the paint tool</source>
        <translation>Ustawia ołówek jako narzędzie do rysowania</translation>
    </message>
</context>
<context>
    <name>PinTool</name>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="40"/>
        <source>Pin Tool</source>
        <translation>Narzędzie przypinania</translation>
    </message>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="52"/>
        <source>Pin image on the desktop</source>
        <translation>Przypnij obrazek do pulpitu</translation>
    </message>
</context>
<context>
    <name>PixelateTool</name>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="40"/>
        <source>Pixelate</source>
        <translation>Zamazywanie</translation>
    </message>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="52"/>
        <source>Set Pixelate as the paint tool</source>
        <translation>Ustaw Zamazywanie jako narzędzie malowania</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="112"/>
        <source>Save Error</source>
        <translation>Błąd zapisu</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="66"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="107"/>
        <source>Capture saved as </source>
        <translation>Zaznaczenie zapisano jako </translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="42"/>
        <source>Capture saved to clipboard.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="47"/>
        <source>Capture saved to clipboard</source>
        <translation>Zrzut skopiowano do schowka</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="69"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="110"/>
        <source>Error trying to save as </source>
        <translation>Błąd przy próbie zapisu jako </translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="82"/>
        <location filename="../../src/main.cpp" line="244"/>
        <location filename="../../src/main.cpp" line="399"/>
        <location filename="../../src/main.cpp" line="426"/>
        <location filename="../../src/main.cpp" line="458"/>
        <source>Unable to connect via DBus</source>
        <translation>Nie udało się połączyć za pomocą DBus</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="104"/>
        <source>Powerful yet simple to use screenshot software.</source>
        <translation>Zaawansowany lecz prosty w użyciu program do zrzutów ekranu.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="105"/>
        <source>See</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="108"/>
        <source>Capture the entire desktop.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="110"/>
        <source>Open the capture launcher.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="112"/>
        <source>Start a manual capture in GUI mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="114"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="116"/>
        <source>Capture a single screen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="120"/>
        <source>Path where the capture will be saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="123"/>
        <source>Save the capture to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="125"/>
        <source>Delay time in milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="128"/>
        <source>Set the filename pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="131"/>
        <source>Enable or disable the trayicon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="134"/>
        <source>Enable or disable run at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="138"/>
        <source>Show the help message in the capture mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="141"/>
        <source>Define the main UI color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="144"/>
        <source>Define the contrast UI color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="147"/>
        <source>Print raw PNG capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="150"/>
        <source>Define the screen to capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="151"/>
        <source>default: screen containing the cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="152"/>
        <source>Screen number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="161"/>
        <source>Invalid color, this flag supports the following formats:
- #RGB (each of R, G, and B is a single hex digit)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- Named colors like &apos;blue&apos; or &apos;red&apos;
You may need to escape the &apos;#&apos; sign as in &apos;\#FFF&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="170"/>
        <source>Invalid delay, it must be higher than 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="172"/>
        <source>Invalid screen number, it must be non negative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="179"/>
        <source>Invalid path, it must be a real path in the system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="189"/>
        <source>Invalid value, it must be defined as &apos;true&apos; or &apos;false&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="45"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="46"/>
        <source>Unable to write in</source>
        <translation>Nie można zapisać w</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="88"/>
        <source>URL copied to clipboard.</source>
        <translation>URL skopiowany do schowka.</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="64"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="77"/>
        <source>Arguments</source>
        <translation>Argumenty</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="350"/>
        <source>arguments</source>
        <translation>argumenty</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>Usage</source>
        <translation>Użycie</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>options</source>
        <translation>opcje</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="358"/>
        <source>Per default runs Flameshot in the background and   adds a tray icon for configuration.</source>
        <translation>Domyślnie uruchamia Flameshot w tle i dodaje ikonę w zasobniku systemowym do konfiguracji.</translation>
    </message>
</context>
<context>
    <name>RectangleTool</name>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="52"/>
        <source>Set the Rectangle as the paint tool</source>
        <translation>Ustawia prostokąt jako narzędzie do rysowania</translation>
    </message>
</context>
<context>
    <name>RedoTool</name>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="40"/>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="52"/>
        <source>Redo the next modification</source>
        <translation>Ponów następną modyfikację</translation>
    </message>
</context>
<context>
    <name>SaveTool</name>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="41"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="53"/>
        <source>Save the capture</source>
        <translation>Zapisz zaznaczenie</translation>
    </message>
</context>
<context>
    <name>ScreenGrabber</name>
    <message>
        <location filename="../../src/utils/screengrabber.cpp" line="84"/>
        <source>Unable to capture screen</source>
        <translation>Nie można przechwycić ekranu</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="46"/>
        <source>Rectangular Selection</source>
        <translation>Zaznaczenie prostokątne</translation>
    </message>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="58"/>
        <source>Set Selection as the paint tool</source>
        <translation>Ustawia zaznaczenie prostokątne jako narzędzie do rysowania</translation>
    </message>
</context>
<context>
    <name>SidePanelWidget</name>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="71"/>
        <source>Active thickness:</source>
        <translation>Grubość:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="72"/>
        <source>Active color:</source>
        <translation>Kolor:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="217"/>
        <source>Press ESC to cancel</source>
        <translation>Wciśnij ESC, aby anulować</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="219"/>
        <source>Grab Color</source>
        <translation>Pobierz kolor</translation>
    </message>
</context>
<context>
    <name>SizeIndicatorTool</name>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="40"/>
        <source>Selection Size Indicator</source>
        <translation>Miernik zaznaczenia</translation>
    </message>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="52"/>
        <source>Show the dimensions of the selection (X Y)</source>
        <translation>Pokazuje wymiary zaznaczenia (X Y)</translation>
    </message>
</context>
<context>
    <name>StrftimeChooserWidget</name>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="50"/>
        <source>Century (00-99)</source>
        <translation>Wiek (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="51"/>
        <source>Year (00-99)</source>
        <translation>Rok (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="52"/>
        <source>Year (2000)</source>
        <translation>Rok (2000)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="53"/>
        <source>Month Name (jan)</source>
        <translation>Nazwa miesiąca (cze)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="54"/>
        <source>Month Name (january)</source>
        <translation>Nazwa miesiąca (czerwiec)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="55"/>
        <source>Month (01-12)</source>
        <translation>Miesiąc (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="56"/>
        <source>Week Day (1-7)</source>
        <translation>Dzień tygodnia (1-7)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="57"/>
        <source>Week (01-53)</source>
        <translation>Tydzień (01-53)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="58"/>
        <source>Day Name (mon)</source>
        <translation>Nazwa dniaa (pią)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="59"/>
        <source>Day Name (monday)</source>
        <translation>Nazwa dnia (piątek)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="60"/>
        <source>Day (01-31)</source>
        <translation>Dzień (01-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="61"/>
        <source>Day of Month (1-31)</source>
        <translation>Dzień miesiąca (1-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="62"/>
        <source>Day (001-366)</source>
        <translation>Dzień (001-366)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="63"/>
        <source>Time (%H-%M-%S)</source>
        <translation>Czas (%H-%M-%S)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="64"/>
        <source>Time (%H-%M)</source>
        <translation>Czas (%H-%M)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="65"/>
        <source>Hour (00-23)</source>
        <translation>Godzina (00-23)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="66"/>
        <source>Hour (01-12)</source>
        <translation>Godzina (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="67"/>
        <source>Minute (00-59)</source>
        <translation>Minuta (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="68"/>
        <source>Second (00-59)</source>
        <translation>Sekunda (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="69"/>
        <source>Full Date (%m/%d/%y)</source>
        <translation>Data (%m/%d/%y)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="70"/>
        <source>Full Date (%Y-%m-%d)</source>
        <translation>Data (%Y-%m-%d)</translation>
    </message>
</context>
<context>
    <name>SystemNotification</name>
    <message>
        <location filename="../../src/utils/systemnotification.cpp" line="36"/>
        <source>Flameshot Info</source>
        <translation>Flameshot Info</translation>
    </message>
</context>
<context>
    <name>TextConfig</name>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="54"/>
        <source>StrikeOut</source>
        <translation>Przekreślenie</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="63"/>
        <source>Underline</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="72"/>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="81"/>
        <source>Italic</source>
        <translation>Kursywa</translation>
    </message>
</context>
<context>
    <name>TextTool</name>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="63"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="75"/>
        <source>Add text to your capture</source>
        <translation>Dodaje tekst do zrzutu</translation>
    </message>
</context>
<context>
    <name>UIcolorEditor</name>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="32"/>
        <source>UI Color Editor</source>
        <translation>Edytor kolorów interfejsu</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="107"/>
        <source>Change the color moving the selectors and see the changes in the preview buttons.</source>
        <translation>Zmień kolor przesuwając selektory i obserwując podgląd przycisków.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="119"/>
        <source>Select a Button to modify it</source>
        <translation>Wybierz przycisk do zmodyfikowania</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="129"/>
        <source>Main Color</source>
        <translation>Kolor główny</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="133"/>
        <source>Click on this button to set the edition mode of the main color.</source>
        <translation>Kliknij na przycisk aby móc modyfikować kolor główny.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="144"/>
        <source>Contrast Color</source>
        <translation>Kolor kontrastowy</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="149"/>
        <source>Click on this button to set the edition mode of the contrast color.</source>
        <translation>Kliknij na przycisk aby móc modyfikować kolor kontrastowy.</translation>
    </message>
</context>
<context>
    <name>UndoTool</name>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="40"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="52"/>
        <source>Undo the last modification</source>
        <translation>Cofnij ostatnią zmianę</translation>
    </message>
</context>
<context>
    <name>UtilityPanel</name>
    <message>
        <location filename="../../src/widgets/panel/utilitypanel.cpp" line="114"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualsEditor</name>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="61"/>
        <source>Opacity of area outside selection:</source>
        <translation>Przezroczystość obszaru poza zaznaczeniem:</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="89"/>
        <source>Button Selection</source>
        <translation>Wybór przycisków</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="95"/>
        <source>Select All</source>
        <translation>Wybierz wszystkie</translation>
    </message>
</context>
</TS>
